# Tutorials

These tutorials walk through how to use Starsim. If you want to explore them interactively, you can run them on Binder via http://tutorials.starsim.org. To run locally, start a Jupyter environment in this folder (`docs/tutorials`). You can use either `jupyter lab` or `jupyter notebook` to run these tutorials.